<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Core\Content\Product\Cms;

use Shopware\Core\Content\Cms\Aggregate\CmsSlot\CmsSlotEntity;
use Shopware\Core\Content\Cms\DataResolver\CriteriaCollection;
use Shopware\Core\Content\Cms\DataResolver\Element\CmsElementResolverInterface;
use Shopware\Core\Content\Cms\DataResolver\Element\ElementDataCollection;
use Shopware\Core\Content\Cms\DataResolver\ResolverContext\ResolverContext;
use Shopware\Core\Content\Product\ProductDefinition;

class ProductBoxCmsElementResolver implements CmsElementResolverInterface
{
    public function __construct(
        private readonly CmsElementResolverInterface $mainService,
    ) {
    }

    public function getType(): string
    {
        return $this->mainService->getType();
    }

    public function collect(CmsSlotEntity $slot, ResolverContext $resolverContext): ?CriteriaCollection
    {
        $criteriaCollection = $this->mainService->collect($slot, $resolverContext);

        if ($criteriaCollection instanceof CriteriaCollection) {
            foreach ($criteriaCollection as $definition => $criterias) {
                if (ProductDefinition::class !== $definition) {
                    continue;
                }

                foreach ($criterias as $criteria) {
                    $criteria->addAssociation('options.group');
                }
            }
        }

        return $criteriaCollection;
    }

    public function enrich(CmsSlotEntity $slot, ResolverContext $resolverContext, ElementDataCollection $result): void
    {
        $this->mainService->enrich($slot, $resolverContext, $result);
    }
}
