<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Core\Content\PropertyGroupOption\Aggregate\OptionAttribute;

use NetInventors\NetiNextToolKit\Core\Content\PropertyGroupOption\Aggregate\OptionAttribute\Translation\OptionAttributeTranslationDefinition;
use Shopware\Core\Content\Property\Aggregate\PropertyGroupOption\PropertyGroupOptionDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\EntityDefinition;
use Shopware\Core\Framework\DataAbstractionLayer\Field\FkField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\PrimaryKey;
use Shopware\Core\Framework\DataAbstractionLayer\Field\Flag\Required;
use Shopware\Core\Framework\DataAbstractionLayer\Field\IdField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\OneToOneAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\TranslatedField;
use Shopware\Core\Framework\DataAbstractionLayer\Field\TranslationsAssociationField;
use Shopware\Core\Framework\DataAbstractionLayer\FieldCollection;

/**
 * @psalm-suppress PropertyNotSetInConstructor
 */
class OptionAttributeDefinition extends EntityDefinition
{
    final public const ENTITY_NAME = 'neti_tk_option_attr';

    public function getEntityName(): string
    {
        return self::ENTITY_NAME;
    }

    public function getEntityClass(): string
    {
        return OptionAttributeEntity::class;
    }

    public function getCollectionClass(): string
    {
        return OptionAttributeCollection::class;
    }

    protected function defineFields(): FieldCollection
    {
        return new FieldCollection(
            [
                (new IdField('id', 'id'))->addFlags(new PrimaryKey(), new Required()),

                (new OneToOneAssociationField(
                    'propertyGroupOption',
                    'property_group_option_id',
                    'id',
                    PropertyGroupOptionDefinition::class,
                    false,
                )),
                (new FkField('property_group_option_id', 'propertyGroupOption', PropertyGroupOptionDefinition::class)),

                // Translations
                new TranslatedField('textField1'),
                new TranslatedField('textField2'),
                new TranslatedField('textField3'),
                new TranslatedField('textArea1'),
                new TranslatedField('htmlText1'),

                (new TranslationsAssociationField(
                    OptionAttributeTranslationDefinition::class,
                    'neti_tk_option_attr_id',
                )),
            ],
        );
    }
}
