<?php

declare(strict_types=1);

namespace NetInventors\NetiNextToolKit\Migration;

use Doctrine\DBAL\Connection;
use Shopware\Core\Framework\Migration\MigrationStep;

class Migration1664177534 extends MigrationStep
{
    public function getCreationTimestamp(): int
    {
        return 1_664_177_534;
    }

    public function update(Connection $connection): void
    {
        $this->createOptionAttributeTable($connection);
        $this->createOptionAttributeTableTranslation($connection);
    }

    public function updateDestructive(Connection $connection): void
    {
        // implement update destructive
    }

    private function createOptionAttributeTable(Connection $connection): void
    {
        $sql = <<<SQL
CREATE TABLE IF NOT EXISTS `neti_tk_option_attr` (
`id` BINARY(16) NOT NULL,
    `property_group_option_id` BINARY(16) NULL,
    `created_at` DATETIME(3) NOT NULL,
    `updated_at` DATETIME(3) NULL,
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
SQL;
        $connection->executeStatement($sql);
    }

    private function createOptionAttributeTableTranslation(Connection $connection): void
    {
        $sql = <<<SQL
CREATE TABLE IF NOT EXISTS `neti_tk_option_attr_translation` (
`text_field_1` VARCHAR(255) NULL,
    `text_field_2` VARCHAR(255) NULL,
    `text_field_3` VARCHAR(255) NULL,
    `html_text_1` LONGTEXT NULL,
    `text_area_1` LONGTEXT NULL,
    `created_at` DATETIME(3) NOT NULL,
    `updated_at` DATETIME(3) NULL,
    `neti_tk_option_attr_id` BINARY(16) NOT NULL,
    `language_id` BINARY(16) NOT NULL,
    PRIMARY KEY (`neti_tk_option_attr_id`,`language_id`),
    KEY `fk.neti_tk_option_attr_translation.neti_tk_option_attr_id` (`neti_tk_option_attr_id`),
    KEY `fk.neti_tk_option_attr_translation.language_id` (`language_id`),
    CONSTRAINT `fk.neti_tk_option_attr_translation.neti_tk_option_attr_id` FOREIGN KEY (`neti_tk_option_attr_id`) REFERENCES `neti_tk_option_attr` (`id`) ON DELETE CASCADE ON UPDATE CASCADE,
    CONSTRAINT `fk.neti_tk_option_attr_translation.language_id` FOREIGN KEY (`language_id`) REFERENCES `language` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
SQL;
        $connection->executeStatement($sql);
    }
}
